@@ -140,7 +140,7 @@ GNUNET_FS_GTK_add_meta_data_to_list_store (void *cls,
  */
 GdkPixbuf *
 GNUNET_FS_GTK_get_thumbnail_from_meta_data (
-  const struct GNUNET_CONTAINER_MetaData *meta)
+  const struct GNUNET_FS_MetaData *meta)
 {
   GdkPixbuf *pixbuf;
   GdkPixbufLoader *loader;
@@ -148,7 +148,7 @@ GNUNET_FS_GTK_get_thumbnail_from_meta_data (
   unsigned char *thumb;
 
   thumb = NULL;
-  ts = GNUNET_CONTAINER_meta_data_get_thumbnail (meta, &thumb);
+  ts = GNUNET_FS_meta_data_get_thumbnail (meta, &thumb);
   if (0 == ts)
     return NULL;
   loader = gdk_pixbuf_loader_new ();
@@ -242,13 +242,13 @@ GNUNET_FS_GTK_mmap_and_scan (const char *filename,
  */
 char *
 GNUNET_FS_GTK_get_description_from_metadata (
-  const struct GNUNET_CONTAINER_MetaData *meta,
+  const struct GNUNET_FS_MetaData *meta,
   int *is_a_dup)
 {
   char *desc;
   char *utf8_desc;
 
-  desc = GNUNET_CONTAINER_meta_data_get_first_by_types (
+  desc = GNUNET_FS_meta_data_get_first_by_types (
     meta,
     EXTRACTOR_METATYPE_PACKAGE_NAME,
     EXTRACTOR_METATYPE_TITLE,
