@@ -35,7 +35,7 @@
  * Be very verbose when reporting progress (usually bad as it takes more time
  * to display this than to make progress).
  */
-#define VERBOSE_PROGRESS GNUNET_EXTRA_LOGGING
+#define VERBOSE_PROGRESS GNUNET_GTK_EXTRA_LOGGING
 
 /**
  * Columns in the publish model.
@@ -586,17 +586,17 @@ create_dir_at_iter (struct MainPublishingDialogContext *ctx,
   struct GNUNET_FS_FileInformation *fi;
   GtkTreeRowReference *row_reference;
   GtkTreePath *path;
-  struct GNUNET_CONTAINER_MetaData *meta;
+  struct GNUNET_FS_MetaData *meta;
 
-  meta = GNUNET_CONTAINER_meta_data_create ();
+  meta = GNUNET_FS_meta_data_create ();
   GNUNET_FS_meta_data_make_directory (meta);
-  GNUNET_CONTAINER_meta_data_insert (meta,
-                                     "<gnunet-gtk>",
-                                     EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
-                                     EXTRACTOR_METAFORMAT_UTF8,
-                                     "text/plain",
-                                     name,
-                                     strlen (name) + 1);
+  GNUNET_FS_meta_data_insert (meta,
+                              "<gnunet-gtk>",
+                              EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME,
+                              EXTRACTOR_METAFORMAT_UTF8,
+                              "text/plain",
+                              name,
+                              strlen (name) + 1);
   gtk_tree_store_insert_before (GTK_TREE_STORE (ctx->file_info_treemodel),
                                 pos,
                                 iter,
@@ -611,7 +611,7 @@ create_dir_at_iter (struct MainPublishingDialogContext *ctx,
     meta,
     bo,
     name);
-  GNUNET_CONTAINER_meta_data_destroy (meta);
+  GNUNET_FS_meta_data_destroy (meta);
   gtk_tree_store_set (GTK_TREE_STORE (ctx->file_info_treemodel),
                       pos,
                       PUBLISH_MC_FILESIZE,
@@ -1226,7 +1226,7 @@ static int
 free_fi_row_reference (void *cls,
                        struct GNUNET_FS_FileInformation *fi,
                        uint64_t length,
-                       struct GNUNET_CONTAINER_MetaData *meta,
+                       struct GNUNET_FS_MetaData *meta,
                        struct GNUNET_FS_Uri **uri,
                        struct GNUNET_FS_BlockOptions *bo,
                        int *do_index,
@@ -1453,12 +1453,12 @@ add_item (struct AddDirClientContext *adcc,
   {
     /* update meta data mime type (force to be GNUnet-directory) */
     if (NULL != item->meta)
-      GNUNET_CONTAINER_meta_data_delete (item->meta,
-                                         EXTRACTOR_METATYPE_MIMETYPE,
-                                         NULL,
-                                         0);
+      GNUNET_FS_meta_data_delete (item->meta,
+                                  EXTRACTOR_METATYPE_MIMETYPE,
+                                  NULL,
+                                  0);
     else
-      item->meta = GNUNET_CONTAINER_meta_data_create ();
+      item->meta = GNUNET_FS_meta_data_create ();
     GNUNET_FS_meta_data_make_directory (item->meta);
 
     fi = GNUNET_FS_file_information_create_empty_directory (
@@ -2019,7 +2019,7 @@ static int
 update_treeview_after_edit (void *cls,
                             struct GNUNET_FS_FileInformation *fi,
                             uint64_t length,
-                            struct GNUNET_CONTAINER_MetaData *meta,
+                            struct GNUNET_FS_MetaData *meta,
                             struct GNUNET_FS_Uri **uri,
                             struct GNUNET_FS_BlockOptions *bo,
                             int *do_index,
@@ -2028,7 +2028,7 @@ update_treeview_after_edit (void *cls,
   struct EditPublishContext *epc = cls;
   char *name;
 
-  name = GNUNET_CONTAINER_meta_data_get_by_type (
+  name = GNUNET_FS_meta_data_get_by_type (
     meta,
     EXTRACTOR_METATYPE_GNUNET_ORIGINAL_FILENAME);
   gtk_tree_store_set (GTK_TREE_STORE (epc->tm),
@@ -2232,7 +2232,7 @@ static int
 insert_advertisement (void *cls,
                       struct GNUNET_FS_FileInformation *fi,
                       uint64_t length,
-                      struct GNUNET_CONTAINER_MetaData *meta,
+                      struct GNUNET_FS_MetaData *meta,
                       struct GNUNET_FS_Uri **uri,
                       struct GNUNET_FS_BlockOptions *bo,
                       int *do_index,
@@ -2258,13 +2258,13 @@ insert_advertisement (void *cls,
   if (NULL == sks_uri_string)
     return GNUNET_SYSERR;
 
-  GNUNET_CONTAINER_meta_data_insert (meta,
-                                     "<gnunet>",
-                                     EXTRACTOR_METATYPE_URI,
-                                     EXTRACTOR_METAFORMAT_UTF8,
-                                     "text/plain",
-                                     sks_uri_string,
-                                     strlen (sks_uri_string) + 1);
+  GNUNET_FS_meta_data_insert (meta,
+                              "<gnunet>",
+                              EXTRACTOR_METATYPE_URI,
+                              EXTRACTOR_METAFORMAT_UTF8,
+                              "text/plain",
+                              sks_uri_string,
+                              strlen (sks_uri_string) + 1);
   GNUNET_free (sks_uri_string);
   return GNUNET_SYSERR;
 }
@@ -2416,7 +2416,7 @@ static int
 clear_keywords_in_file_information (void *cls,
                                     struct GNUNET_FS_FileInformation *fi,
                                     uint64_t length,
-                                    struct GNUNET_CONTAINER_MetaData *meta,
+                                    struct GNUNET_FS_MetaData *meta,
                                     struct GNUNET_FS_Uri **uri,
                                     struct GNUNET_FS_BlockOptions *bo,
                                     int *do_index,
@@ -2620,7 +2620,7 @@ static void
 add_updateable_to_ts (void *cls,
                       const char *last_id,
                       const struct GNUNET_FS_Uri *last_uri,
-                      const struct GNUNET_CONTAINER_MetaData *last_meta,
+                      const struct GNUNET_FS_MetaData *last_meta,
                       const char *next_id)
 {
   struct UpdateableContext *uc = cls;
@@ -2660,11 +2660,11 @@ add_updateable_to_ts (void *cls,
     urilen = 0;
 
   mdbuf = NULL;
-  mdsize = GNUNET_CONTAINER_meta_data_serialize (
+  mdsize = GNUNET_FS_meta_data_serialize (
     last_meta,
     &mdbuf,
     64 * 1024,
-    GNUNET_CONTAINER_META_DATA_SERIALIZE_FULL);
+    GNUNET_FS_META_DATA_SERIALIZE_FULL);
   if (0 > mdsize)
     mdsize = 0;
 
