@@ -178,9 +178,7 @@ gtk_statistics_init (GtkStatistics *statistics)
 {
   GtkStatisticsPrivate *priv;
 
-  statistics->priv = G_TYPE_INSTANCE_GET_PRIVATE (statistics,
-                                                  GTK_TYPE_STATISTICS,
-                                                  GtkStatisticsPrivate);
+  statistics->priv = gtk_statistics_get_instance_private (statistics);
   priv = statistics->priv;
 #if GTK_MAJOR_VERSION < 3
   g_signal_connect (statistics,
